( cd usr/lib ; rm -rf libtiff.so.3 )
( cd usr/lib ; ln -sf libtiff.so.3.8.2 libtiff.so.3 )
( cd usr/lib ; rm -rf libtiff.so )
( cd usr/lib ; ln -sf libtiff.so.3.8.2 libtiff.so )
( cd usr/lib ; rm -rf libtiffxx.so.3 )
( cd usr/lib ; ln -sf libtiffxx.so.3.8.2 libtiffxx.so.3 )
( cd usr/lib ; rm -rf libtiffxx.so )
( cd usr/lib ; ln -sf libtiffxx.so.3.8.2 libtiffxx.so )
